==> gnash-0.8.6.tar.bz2: gnash-0.8.6/libcore/asobj/flash/text/StaticText_as.cpp <==
// StaticText_as.cpp:  ActionScript "StaticText" class, for Gnash.
//
//   Copyright (C) 2009 Free Software Foundation, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifdef HAVE_CONFIG_H
#include "gnashconfig.h"
#endif

#include "text/StaticText_as.h"
#include "log.h"
#include "fn_call.h"
#include "Global_as.h"
#include "smart_ptr.h" // for boost intrusive_ptr
#include "builtin_function.h" // need builtin_function
#include "GnashException.h" // for ActionException

namespace gnash {

// Forward declarations
namespace {
    as_value statictext_ctor(const fn_call& fn);
    void attachStaticTextInterface(as_object& o);
    void attachStaticTextStaticInterface(as_object& o);
    as_object* getStaticTextInterface();

}

class StaticText_as : public as_object
{

public:

    StaticText_as()
        :
        as_object(getStaticTextInterface())
    {}
};

// extern (used by Global.cpp)
void
statictext_class_init(as_object& where, const ObjectURI& uri)
{
    static boost::intrusive_ptr<as_object> cl;

    if (!cl) {
        Global_as* gl = getGlobal(where);
        as_object* proto = getStaticTextInterface();
        cl = gl->createClass(&statictext_ctor, proto);
        attachStaticTextStaticInterface(*cl);
    }

    // Register _global.StaticText
    where.init_member(getName(uri), cl.get(), as_object::DefaultFlags,
            getNamespace(uri));
}

namespace {

void
attachStaticTextInterface(as_object& /*o*/)
{
}

void
attachStaticTextStaticInterface(as_object& /*o*/)
{

}

as_object*
getStaticTextInterface()
{
    static boost::intrusive_ptr<as_object> o;
    if ( ! o ) {
        o = new as_object();
        attachStaticTextInterface(*o);
    }
    return o.get();
}

as_value
statictext_ctor(const fn_call& /*fn*/)
{
    boost::intrusive_ptr<as_object> obj = new StaticText_as;

    return as_value(obj.get()); // will keep alive
}

} // anonymous namespace 
} // gnash namespace

// local Variables:
// mode: C++
// indent-tabs-mode: t
// End:

==> gnash-0.8.7.tar.bz2: gnash-0.8.7/libcore/asobj/flash/text/StaticText_as.cpp <==
// StaticText_as.cpp:  ActionScript "StaticText" class, for Gnash.
//
//   Copyright (C) 2009, 2010 Free Software Foundation, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//


#include "text/StaticText_as.h"
#include "log.h"
#include "fn_call.h"
#include "Global_as.h"
#include "smart_ptr.h" // for boost intrusive_ptr
#include "builtin_function.h" // need builtin_function
#include "GnashException.h" // for ActionException

namespace gnash {

// Forward declarations
namespace {
    as_value statictext_ctor(const fn_call& fn);
    void attachStaticTextInterface(as_object& o);
    void attachStaticTextStaticInterface(as_object& o);

}

// extern (used by Global.cpp)
void
statictext_class_init(as_object& where, const ObjectURI& uri)
{
    registerBuiltinClass(where, statictext_ctor, attachStaticTextInterface,
            attachStaticTextStaticInterface, uri);
}

namespace {

void
attachStaticTextInterface(as_object& /*o*/)
{
}

void
attachStaticTextStaticInterface(as_object& /*o*/)
{

}

as_value
statictext_ctor(const fn_call& /*fn*/)
{
    return as_value();
}

} // anonymous namespace 
} // gnash namespace

// local Variables:
// mode: C++
// indent-tabs-mode: t
// End:
